#  Copyright 2020  Dominik Sekotill <dom.sekotill@kodo.org.uk>
#
#  This Source Code Form is subject to the terms of the Mozilla Public
#  License, v. 2.0. If a copy of the MPL was not distributed with this
#  file, You can obtain one at http://mozilla.org/MPL/2.0/.

"""
Run pylint from pre-commit with project dependencies installed
"""

import subprocess
import sys
from os.path import isfile

import click
from pylint import lint

__version__ = '0.3'


@click.command(context_settings=dict(
	ignore_unknown_options=True,
))
@click.option(
	'--extras', '-e',
	multiple=True,
	help="The names of optional requirements sets to install",
)
@click.option(
	'--editable/--non-editable',
	default=isfile('setup.py'),
	help="Use the editable install (develop) feature provided by setuptools",
)
@click.argument('pylint-options', nargs=-1, type=click.UNPROCESSED)
def main(extras, editable, pylint_options):
	"""Invoke Pylint on the given files after ensuring dependencies are up to date"""
	join = ','.join
	cmd = ['pip', 'install', '--upgrade']
	if editable:
		# If this looks like a setuptools project, we can install editable
		cmd.append('--editable')
	cmd.append(f'.[{join(extras)}]' if extras else '.')

	try:
		subprocess.run(
			cmd,
			stdout=subprocess.DEVNULL,
			stderr=subprocess.PIPE,
			text=True,
			check=True,
		)
	except subprocess.CalledProcessError as exc:
		sys.stderr.write(exc.stderr)
		sys.exit(3)

	lint.Run(list(pylint_options))


if __name__ == '__main__':
	# pylint: disable=no-value-for-parameter
	main()
